@@ -1,5 +1,7 @@
 """
-Main interface for iot1click-devices service literal definitions.
+Type annotations for iot1click-devices service literal definitions.
+
+[Open documentation](./literals.md)
 
 Usage::
 
